@@ -28,11 +28,11 @@ enum {
     bq_type_notch,
     bq_type_peak,
     bq_type_lowshelf,
-    bq_type_highshelf
+    bq_type_highshelf,
 };
 
 class Biquad {
-public:
+  public:
     Biquad();
     Biquad(int type, double Fc, double Q, double peakGainDB);
     ~Biquad();
@@ -42,8 +42,8 @@ public:
     void setPeakGain(double peakGainDB);
     void setBiquad(int type, double Fc, double Q, double peakGain);
     float process(float in);
-    
-protected:
+
+  protected:
     void calcBiquad(void);
 
     int type;
@@ -52,7 +52,8 @@ protected:
     double z1, z2;
 };
 
-inline float Biquad::process(float in) {
+inline float Biquad::process(float in)
+{
     double out = in * a0 + z1;
     z1 = in * a1 + z2 - b1 * out;
     z2 = in * a2 - b2 * out;
