@@ -7,9 +7,9 @@
 //
 
 #import "CurrentTrackOSX.h"
-#import <iTunes.h>
-#import <Spotify.h>
-#import <VOX.h>
+#import "iTunes.h"
+#import "Spotify.h"
+#import "VOX.h"
 
 const char* getCurrentTrackFromiTunes(int artist_title_order) {
     NSProcessInfo *pInfo = [NSProcessInfo processInfo];
