@@ -26,7 +26,7 @@ void update_samplerates_list(void);
 void update_codec_samplerates(void);
 void update_channel_lists(void);
 void print_info(const char *info, int info_type);
-void write_log(const char *message);
+void write_log(const char *message, const char *path = NULL);
 void print_lcd(const char *text, int len, int home, int clear);
 void test_file_extension(void);
 int expand_string(char **str);
@@ -54,7 +54,7 @@ int get_midi_ctrl_type(int midi_command);
 
 typedef const char *(*currentTrackFunction)(int);
 extern currentTrackFunction getCurrentTrackFunctionFromId(int i);
-int exec_midi_command(int command_id, int value);
+int exec_midi_command(int command_id, int msg_type, int value);
 void populate_midi_dev_list(void);
 
 #endif
