@@ -66,10 +66,10 @@ pthread_t split_recording_file_thread_detached;
 pthread_t request_listener_count_thread_detached;
 pthread_t url_song_update_thread_detached;
 
-ATOM_NEW_INT(url_song_update_thread_running);
-ATOM_NEW_INT(request_listener_count_thread_running);
-ATOM_NEW_INT(g_listener_count);
-ATOM_NEW_INT(failed_get_listener_tries);
+ATOM_NEW_INT(url_song_update_thread_running, 0);
+ATOM_NEW_INT(request_listener_count_thread_running, 0);
+ATOM_NEW_INT(g_listener_count, -1);
+ATOM_NEW_INT(failed_get_listener_tries, 0);
 
 int g_vu_meter_timer_is_active = 0;
 int g_stop_vu_meter_timer = 0;
@@ -301,7 +301,7 @@ void vu_meter_timer(void *)
     }
 }
 
-void display_info_timer(void *)
+void display_info_timer(void *reset)
 {
     char lcd_text_buf[33];
 
@@ -310,6 +310,10 @@ void display_info_timer(void *)
         return;
     }
 
+    if (reset != NULL && *(int *)reset == 1) {
+        atom_set_int(&g_listener_count, -1);
+    }
+
     if (display_info == SENT_DATA) {
         snprintf(lcd_text_buf, sizeof(lcd_text_buf), _("stream sent\n%0.2lfMB"), kbytes_sent / 1024);
         print_lcd(lcd_text_buf, strlen(lcd_text_buf), 0, 1);
@@ -546,7 +550,36 @@ void *request_listener_count_thread_func(void *reset)
 
     atom_set_int(&request_listener_count_thread_running, 1);
 
-    if (cfg.srv[cfg.selected_srv]->type == ICECAST) {
+    if (reset != NULL && *(int *)reset == 1) {
+        got_listener_count = 0;
+    }
+
+    if (cfg.srv[cfg.selected_srv]->custom_listener_url != NULL && strlen(cfg.srv[cfg.selected_srv]->custom_listener_url) > 0) {
+        if (strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/status-json.xsl") != NULL ||
+            strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/7.xsl") != NULL) {
+            char *mount;
+            if (cfg.srv[cfg.selected_srv]->custom_listener_mount != NULL && strlen(cfg.srv[cfg.selected_srv]->custom_listener_mount) > 0) {
+                mount = cfg.srv[cfg.selected_srv]->custom_listener_mount;
+            }
+            else {
+                if (cfg.srv[cfg.selected_srv]->type == ICECAST) {
+                    mount = cfg.srv[cfg.selected_srv]->mount;
+                }
+                else {
+                    mount = NULL;
+                }
+            }
+            listeners = ic_get_listener_count_from_url(cfg.srv[cfg.selected_srv]->custom_listener_url, mount);
+        }
+        else if (strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/stats?sid") != NULL ||
+                 strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/7.html") != NULL) {
+            listeners = sc_get_listener_count_from_url(cfg.srv[cfg.selected_srv]->custom_listener_url);
+        }
+        else {
+            listeners = -1;
+        }
+    }
+    else if (cfg.srv[cfg.selected_srv]->type == ICECAST) {
         listeners = ic_get_listener_count();
     }
     else if (cfg.srv[cfg.selected_srv]->type == SHOUTCAST) {
