@@ -16,15 +16,18 @@
 #ifndef FL_TIMER_FUNCS_H
 #define FL_TIMER_FUNCS_H
 
+void rotate_sponsor_logo_timer(void *);
 void display_info_timer(void *);
 void agent_watchdog_timer(void *);
 void has_agent_been_started_timer(void *);
 void has_agent_been_stopped_timer(void *);
 void vu_meter_timer(void *);
 void cmd_timer(void *);
+void reconnect_timer(void *);
 void is_connected_timer(void *);
 void cfg_win_pos_timer(void *);
 void songfile_timer(void *);
+void song_url_timer(void *);
 void stream_silence_timer(void *);
 void record_silence_timer(void *);
 void stream_signal_timer(void *);
@@ -37,6 +40,10 @@ void app_timer(void *);
 
 void split_recording_file_timer(void);
 void split_recording_file(void);
+void reset_stream_signal_detection_timer(void);
+void reset_stream_silence_detection_timer(void);
+void reset_record_signal_detection_timer(void);
+void reset_record_silence_detection_timer(void);
 
 extern const char *(*current_track_app)(int);
 extern int g_vu_meter_timer_is_active;
