@@ -20,11 +20,7 @@
 
 #ifdef HAVE_LIBFDK_AAC
 
-#if defined(WIN32) || defined(__APPLE__)
 #include "aac_dll.h"
-#else
-#include <fdk-aac/aacenc_lib.h>
-#endif
 
 struct aac_enc {
     HANDLE_AACENCODER handle;
@@ -44,9 +40,10 @@ enum {
 };
 
 int aac_enc_init(aac_enc *aac);
-int aac_enc_encode(aac_enc *aac, float *pcm_buf, char *enc_buf, int samples, int size);
+int aac_enc_encode(aac_enc *aac, float *pcm_buf, char *enc_buf, int samples, int enc_buf_size);
 int aac_enc_get_samplerate(aac_enc *aac);
 int aac_enc_reinit(aac_enc *aac);
+int aac_enc_flush_file(aac_enc *aac, FILE *file);
 void aac_enc_close(aac_enc *aac);
 
 #endif // HAVE_LIBFDK_AAC
