@@ -440,6 +440,20 @@ int cfg_write_file(char *path)
                     cfg.srv[i]->name, WEBRTC);
         }
 
+        if (cfg.srv[i]->custom_listener_url != NULL) {
+            fprintf(cfg_fd, "custom_listener_url = %s\n", cfg.srv[i]->custom_listener_url);
+        }
+        else {
+            fprintf(cfg_fd, "custom_listener_url = \n");
+        }
+
+        if (cfg.srv[i]->custom_listener_mount != NULL) {
+            fprintf(cfg_fd, "custom_listener_mount = %s\n", cfg.srv[i]->custom_listener_mount);
+        }
+        else {
+            fprintf(cfg_fd, "custom_listener_mount = \n");
+        }
+
         if (cfg.srv[i]->cert_hash != NULL) {
             fprintf(cfg_fd, "cert_hash = %s\n", cfg.srv[i]->cert_hash);
         }
@@ -551,6 +565,7 @@ int cfg_set_values(char *path)
     }
 
     if (cfg_parse_file(path) == -1) {
+        DEBUG_LOG("Parsing config failed");
         return 1;
     }
 
@@ -755,6 +770,9 @@ int cfg_set_values(char *path)
                 cfg.selected_srv = i;
             }
 
+            cfg.srv[i]->custom_listener_url = cfg_get_str(srv_ent, "custom_listener_url", NULL);
+            cfg.srv[i]->custom_listener_mount = cfg_get_str(srv_ent, "custom_listener_mount", NULL);
+
             srv_ent = strtok(NULL, ";");
         }
         free(strtok_buf);
