@@ -88,7 +88,7 @@ enum {
 };
 
 enum {
-    MIDI_COMMANDS_COUNT = 10,
+    MIDI_COMMANDS_COUNT = 14,
 };
 
 enum {
@@ -120,6 +120,8 @@ typedef struct {
     char *webrtc_ice;  // ICE server for WebRTC
     char *webrtc_whip; // WHIP URL for WebRTC
     char *webrtc_auth; // WHIP URL Bearer Token for WebRTC
+    char *custom_listener_url;
+    char *custom_listener_mount;
     int port;
     int type;             // SHOUTCAST, ICECAST or WEBRTC
     int tls;              // use tls: 0 = no, 1 = yes
