@@ -18,6 +18,9 @@ DSPEffects::DSPEffects(uint32_t frames, uint8_t channels, uint32_t sampleRate) :
     chans = (channels == 2) ? 2 : 1;
     dsp_size = frames * channels;
 
+    eq_active = 0;
+    drc_active = 0;
+
     for (uint32_t i = 0; i < eq_band_count; i++) {
         eq_bands_left[i] = new Biquad(bq_type_peak, eq_freqs[i] / double(samplerate), 2, cfg.dsp.eq_gain[i]);
         eq_bands_right[i] = new Biquad(bq_type_peak, eq_freqs[i] / double(samplerate), 2, cfg.dsp.eq_gain[i]);
@@ -26,7 +29,7 @@ DSPEffects::DSPEffects(uint32_t frames, uint8_t channels, uint32_t sampleRate) :
 
 bool DSPEffects::hasToProcessSamples()
 {
-    return cfg.main.gain != 1 || cfg.dsp.equalizer || cfg.dsp.compressor;
+    return cfg.main.gain != 1 || eq_active || drc_active;
 }
 
 void DSPEffects::loadEQPreset(const char *preset)
@@ -90,6 +93,9 @@ void DSPEffects::loadEQPreset(const char *preset)
     else if (!strcmp(preset, "Vocal Booster")) {
         gain_vals = eq_vocal_booster;
     }
+    else {
+        return;
+    }
 
     for (uint32_t i = 0; i < eq_band_count; i++) {
         setEQband(0, gain_vals[i]);
@@ -183,7 +189,7 @@ void DSPEffects::processSamples(float *audio_buf)
         }
     }
 
-    if (cfg.dsp.compressor) {
+    if (drc_active) {
         attack_const = expf(-1.0f / (cfg.dsp.attack * samplerate));
         release_const = expf(-1.0f / (cfg.dsp.release * samplerate));
 
@@ -198,7 +204,7 @@ void DSPEffects::processSamples(float *audio_buf)
         compress(audio_buf);
     }
 
-    if (cfg.dsp.equalizer) {
+    if (eq_active) {
         for (uint32_t i = 0; i < dsp_size; i += chans) {
             float s = audio_buf[i];
             for (int32_t j = eq_band_count - 1; j >= 0; j--) {
