@@ -610,6 +610,105 @@ void ic_disconnect(void)
     sock_close(stream_socket);
 }
 
+int ic_parse_7_xsl_response(char *response)
+{
+    char *p = response;
+    int num_fields = 0;
+    while (*(p++)) {
+        if (*p == ',') {
+            num_fields++;
+        }
+    }
+    if (num_fields == 6) {
+        p = strchr(response, '>'); // Point to end of the HTML part
+        if (p != NULL) {
+            p++;                       // Point to the listener number
+            char *p2 = strchr(p, ','); // Point to the first delimiter
+            if (p2 != NULL) {
+                *p2 = '\0'; // Null terminate the listener number string
+            }
+            server_type = IC_TYPE_KH;
+            return atoi(p);
+        }
+    }
+    return -1;
+}
+
+int ic_parse_json_xsl_response(char *response, char *mount)
+{
+    cJSON *answer_obj = cJSON_Parse(response);
+
+    if (answer_obj != NULL) {
+        cJSON *icestats = cJSON_GetObjectItemCaseSensitive(answer_obj, "icestats");
+        cJSON *sources = cJSON_GetObjectItemCaseSensitive(icestats, "source");
+
+        // There is more than one source connected to the icecast server,
+        // so we have to find the correct listeners entry by searching for our mountpoint
+        if (cJSON_IsArray(sources) == true) {
+            char tmp_mount[128];
+            if (mount != NULL) {
+                if (strrchr(mount, '/') != NULL) {
+                    mount++;
+                }
+                snprintf(tmp_mount, sizeof(tmp_mount), "%s", mount);
+            }
+            else {
+                snprintf(tmp_mount, sizeof(tmp_mount), "%s", "stream");
+            }
+            cJSON *source;
+            cJSON_ArrayForEach(source, sources)
+            {
+                cJSON *listen_url = cJSON_GetObjectItemCaseSensitive(source, "listenurl");
+                if (cJSON_IsString(listen_url) == true) {
+                    char *json_mount = strrchr(cJSON_GetStringValue(listen_url), '/');
+                    if (json_mount != NULL) {
+                        json_mount++;
+
+                        if (strcmp(json_mount, tmp_mount) == 0) {
+                            cJSON *listeners = cJSON_GetObjectItemCaseSensitive(source, "listeners");
+                            if (cJSON_IsNumber(listeners) == true) {
+                                int num = listeners->valueint;
+                                cJSON_Delete(answer_obj);
+                                return num;
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        else { // There is only one source is connected to the server
+            cJSON *listeners = cJSON_GetObjectItemCaseSensitive(sources, "listeners");
+            if (cJSON_IsNumber(listeners) == true) {
+                int num = listeners->valueint;
+                cJSON_Delete(answer_obj);
+                return num;
+            }
+        }
+    }
+    return -1;
+}
+
+int ic_get_listener_count_from_url(char *url, char *mount)
+{
+    uint32_t data_size;
+    char recv_buf[100 * 1024];
+
+    if (strstr(url, "/status-json.xsl") != NULL) {
+        data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
+        if (data_size > 0) {
+            return ic_parse_json_xsl_response(recv_buf, mount);
+        }
+    }
+    else if (strstr(url, "/7.xsl") != NULL) {
+        data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
+        if (data_size > 0) {
+            return ic_parse_7_xsl_response(recv_buf);
+        }
+    }
+
+    return -1;
+}
+
 int ic_get_listener_count(void)
 {
     uint32_t data_size;
@@ -629,50 +728,18 @@ int ic_get_listener_count(void)
         data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
 
         if (data_size > 0) {
-            cJSON *answer_obj = cJSON_Parse(recv_buf);
-
-            if (answer_obj != NULL) {
-                cJSON *icestats = cJSON_GetObjectItemCaseSensitive(answer_obj, "icestats");
-                cJSON *sources = cJSON_GetObjectItemCaseSensitive(icestats, "source");
-
-                // There is more than one source connected to the icecast server,
-                // so we have to find the correct listeners entry by searching for our mountpoint
-                if (cJSON_IsArray(sources) == true) {
-                    cJSON *source;
-                    cJSON_ArrayForEach(source, sources)
-                    {
-                        cJSON *listen_url = cJSON_GetObjectItemCaseSensitive(source, "listenurl");
-                        if (cJSON_IsString(listen_url) == true) {
-                            char *mount = strrchr(cJSON_GetStringValue(listen_url), '/');
-                            if (mount != NULL) {
-                                mount++;
-                                char *local_mount = cfg.srv[cfg.selected_srv]->mount;
-                                if (strrchr(local_mount, '/') != NULL) {
-                                    local_mount++;
-                                }
-                                if (strcmp(mount, local_mount) == 0) {
-                                    cJSON *listeners = cJSON_GetObjectItemCaseSensitive(source, "listeners");
-                                    if (cJSON_IsNumber(listeners) == true) {
-                                        int num = listeners->valueint;
-                                        server_type = IC_TYPE_VANILLA;
-                                        cJSON_Delete(answer_obj);
-                                        return num;
-                                    }
-                                }
-                            }
-                        }
-                    }
-                }
-                else { // There is only one source is connected to the server
-                    cJSON *listeners = cJSON_GetObjectItemCaseSensitive(sources, "listeners");
-                    if (cJSON_IsNumber(listeners) == true) {
-                        int num = listeners->valueint;
-                        server_type = IC_TYPE_VANILLA;
-                        cJSON_Delete(answer_obj);
-                        return num;
-                    }
-                }
+            char *mount;
+            if (cfg.srv[cfg.selected_srv]->custom_listener_mount != NULL && strlen(cfg.srv[cfg.selected_srv]->custom_listener_mount) > 0) {
+                mount = cfg.srv[cfg.selected_srv]->custom_listener_mount;
             }
+            else {
+                mount = cfg.srv[cfg.selected_srv]->mount;
+            }
+            int listener = ic_parse_json_xsl_response(recv_buf, mount);
+            if (listener != -1) {
+                server_type = IC_TYPE_VANILLA;
+            }
+            return listener;
         }
     }
 
@@ -688,25 +755,11 @@ int ic_get_listener_count(void)
         data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
 
         if (data_size > 0) {
-            char *p = recv_buf;
-            int num_fields = 0;
-            while (*(p++)) {
-                if (*p == ',') {
-                    num_fields++;
-                }
-            }
-            if (num_fields == 6) {
-                p = strchr(recv_buf, '>'); // Point to end of the HTML part
-                if (p != NULL) {
-                    p++;                       // Point to the listener number
-                    char *p2 = strchr(p, ','); // Point to the first delimiter
-                    if (p2 != NULL) {
-                        *p2 = '\0'; // Null terminate the listener number string
-                    }
-                    server_type = IC_TYPE_KH;
-                    return atoi(p);
-                }
+            int listener = ic_parse_7_xsl_response(recv_buf);
+            if (listener != -1) {
+                server_type = IC_TYPE_KH;
             }
+            return listener;
         }
     }
     return -1;
