@@ -22,7 +22,8 @@
 struct lame_enc {
     lame_global_flags *gfp;
     int bitrate;
-    int samplerate;
+    int samplerate_in;
+    int samplerate_out;
     int channel;
     volatile int state;
 
@@ -32,6 +33,12 @@ struct lame_enc {
     int vbr_quality;
     int vbr_min_bitrate;
     int vbr_max_bitrate;
+    int vbr_force_min_bitrate;
+
+    float lowpass_freq;
+    float lowpass_width;
+    float highpass_freq;
+    float highpass_width;
 };
 
 enum {
@@ -41,7 +48,8 @@ enum {
 
 int lame_enc_init(lame_enc *lame);
 int lame_enc_get_samplerate(lame_enc *lame);
-int lame_enc_encode(lame_enc *lame, float *pcm_buf, char *enc_buf, int samples, int size);
+int lame_enc_encode(lame_enc *lame, float *pcm_buf, char *enc_buf, int samples, int buf_size);
+int lame_enc_flush_file(lame_enc *lame, FILE *file);
 int lame_enc_reinit(lame_enc *lame);
 void lame_enc_close(lame_enc *lame);
 
