@@ -34,7 +34,7 @@
 #define OPUS_STATE_NEW_SONG_AVAILABLE 4
 
 #define OPUS_FRAME_SIZE 960 // Must be multiple of 120 (120 = 2,5ms, 960 = 20ms)
-//#define OPUS_FRAME_SIZE (960/2) // Must be multiple of 120 (120 = 2,5ms, 960 = 20ms)
+// #define OPUS_FRAME_SIZE (960/2) // Must be multiple of 120 (120 = 2,5ms, 960 = 20ms)
 #define DEFAULT_OPUS_BITRATE 128000
 
 typedef struct {
@@ -79,7 +79,8 @@ struct opus_enc {
     char song_title[256];
 
     unsigned char *buffer;
-    unsigned char *buffer_last;
+    int buffer_len;
+    float *last_pcm_packet;
 };
 
 enum {
@@ -87,17 +88,13 @@ enum {
     OPUS_BUSY = 1,
 };
 
-// extern opus_info  opus_vi;
-extern OpusEncoder opus_vi;
-extern char *opus_buf;
 int opus_header_to_packet(const OpusHeader *h, unsigned char *packet, int len);
-
 int opus_enc_alloc(opus_enc *opus);
 int opus_enc_init(opus_enc *opus);
 int opus_enc_reinit(opus_enc *opus);
 
 void opus_enc_write_header(opus_enc *opus);
-int opus_enc_encode(opus_enc *opus, float *pcm_buf, char *enc_buf, int size);
+int opus_enc_encode(opus_enc *opus, float *pcm_buf, char *enc_buf);
 int opus_enc_flush(opus_enc *opus, char *enc_buf);
 void opus_enc_close(opus_enc *opus);
 
