@@ -94,7 +94,7 @@ SRC_DATA srconv_dev2;
 ATOM_NEW_COND(stream_cond);
 ATOM_NEW_COND(rec_cond);
 
-ATOM_NEW_INT(close_mixer_thread);
+ATOM_NEW_INT(close_mixer_thread, 0);
 
 pthread_t rec_thread_detached;
 pthread_t stream_thread_detached;
@@ -129,7 +129,7 @@ int snd_init(void)
     PaError p_err;
     if ((p_err = Pa_Initialize()) != paNoError) {
         snprintf(info_buf, sizeof(info_buf), _("PortAudio init failed:\n%s\n"), Pa_GetErrorText(p_err));
-
+        DEBUG_LOG(info_buf);
         fl_alert("%s", info_buf);
         return 1;
     }
