@@ -18,24 +18,22 @@
 
 #include <pthread.h>
 
-struct ringbuf {
-	char *buf;
-	char *w_ptr;
-	char *r_ptr;
-	unsigned int size;
-	unsigned int full;
+typedef struct ringbuf {
+    char *buf;
+    char *w_ptr;
+    char *r_ptr;
+    unsigned int size;
+    unsigned int full;
     pthread_mutex_t mutex;
-}; 
+} ringbuf_t;
 
-
-int rb_init(struct ringbuf *rb, unsigned int size);
-int rb_filled(struct ringbuf *rb);
-int rb_space(struct ringbuf *rb);
-unsigned int rb_read(struct ringbuf *rb, char *dest);
-unsigned int rb_read_len(struct ringbuf *rb, char *dest, unsigned int len);
-
-int rb_write(struct ringbuf *rb, char* src, unsigned int size);
-int rb_free(struct ringbuf *rb);
+int rb_init(ringbuf_t *rb, unsigned int size);
+int rb_filled(ringbuf_t *rb);
+int rb_space(ringbuf_t *rb);
+unsigned int rb_read(ringbuf_t *rb, char *dest);
+unsigned int rb_read_len(ringbuf_t *rb, char *dest, unsigned int len);
+int rb_write(ringbuf_t *rb, char *src, unsigned int size);
+int rb_clear(ringbuf_t *rb);
+int rb_free(ringbuf_t *rb);
 
 #endif /*RINGBUFFER_H*/
-
