@@ -283,17 +283,81 @@ void sc_disconnect(void)
     sock_close(stream_socket);
 }
 
+int sc_parse_sc1_response(char *response)
+{
+    char *listeners;
+    char *listeners_start;
+    char *listeners_end;
+
+    // <HTML><meta http-equiv="Pragma" content="no-cache"></head><body>0,1,1,25,0,128,</body></html>
+    // Numbers in comma list mean:
+    // current_listeners,server_online,peak_listers,max_allowed_isteners,uniq,bitrate,songname
+    listeners_start = strstr(strtolower(response), "<body>");
+    if (listeners_start != NULL) {
+        listeners_end = strchr(listeners_start, ',');
+        if (listeners_end != NULL) {
+            listeners = listeners_start + strlen("<body>");
+            *listeners_end = '\0';
+            return atoi(listeners);
+        }
+    }
+
+    return -1;
+}
+
+int sc_parse_sc2_response(char *response)
+{
+    char *listeners;
+    char *listeners_start;
+    char *listeners_end;
+
+    listeners_start = strstr(strtoupper(response), "<CURRENTLISTENERS>");
+    listeners_end = strstr(strtoupper(response), "</CURRENTLISTENERS>");
+    if (listeners_start != NULL && listeners_end != NULL) {
+        listeners = listeners_start + strlen("<CURRENTLISTENERS>");
+        *listeners_end = '\0';
+        return atoi(listeners);
+    }
+
+    return -1;
+}
+
+int sc_get_listener_count_from_url(char *url)
+{
+    uint32_t data_size;
+    char recv_buf[100 * 1024];
+    if (strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/stats?sid") != NULL) {
+        data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
+        if (data_size > 0) {
+            return sc_parse_sc2_response(recv_buf);
+        }
+    }
+    else if (strstr(cfg.srv[cfg.selected_srv]->custom_listener_url, "/7.html") != NULL) {
+        data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
+        if (data_size > 0) {
+            return sc_parse_sc1_response(recv_buf);
+        }
+    }
+
+    return -1;
+}
+
 int sc_get_listener_count(void)
 {
     uint32_t data_size;
     char *sid;
-    char *listeners;
-    char *listeners_start;
-    char *listeners_end;
     char url[256];
     char proto[8];
     char recv_buf[100 * 1024];
 
+    /*
+    if (cfg.srv[cfg.selected_srv]->tls == 1) {
+        strncpy(proto, "https", sizeof(proto));
+    }
+    else {
+        strncpy(proto, "http", sizeof(proto));
+    }
+    */
     strncpy(proto, "http", sizeof(proto));
 
     if (server_version == SC_VERSION_2 || server_version == SC_VERSION_UNKNOWN) {
@@ -307,36 +371,31 @@ int sc_get_listener_count(void)
         }
 
         data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
-
         if (data_size > 0) {
-            listeners_start = strstr(strtoupper(recv_buf), "<CURRENTLISTENERS>");
-            listeners_end = strstr(strtoupper(recv_buf), "</CURRENTLISTENERS>");
-            if (listeners_start != NULL && listeners_end != NULL) {
-                listeners = listeners_start + strlen("<CURRENTLISTENERS>");
-                *listeners_end = '\0';
+            int listener = sc_parse_sc2_response(recv_buf);
+            if (listener != -1) {
                 server_version = SC_VERSION_2;
-                return atoi(listeners);
             }
+            return listener;
         }
     }
 
     if (server_version == SC_VERSION_1 || server_version == SC_VERSION_UNKNOWN) {
-        snprintf(url, sizeof(url), "%s://%s:%d/7.html", proto, cfg.srv[cfg.selected_srv]->addr, cfg.srv[cfg.selected_srv]->port);
+        if (cfg.srv[cfg.selected_srv]->custom_listener_url == NULL || strlen(cfg.srv[cfg.selected_srv]->custom_listener_url) == 0) {
+            snprintf(url, sizeof(url), "%s://%s:%d/7.html", proto, cfg.srv[cfg.selected_srv]->addr, cfg.srv[cfg.selected_srv]->port);
+        }
+        else {
+            snprintf(url, sizeof(url), "%s", cfg.srv[cfg.selected_srv]->custom_listener_url);
+        }
 
         data_size = url_get_listener_count(url, recv_buf, sizeof(recv_buf));
 
-        // <HTML><meta http-equiv="Pragma" content="no-cache"></head><body>0,1,1,25,0,128,</body></html>
-        // Numbers in comma list mean:
-        // current_listeners,server_online,peak_listers,max_allowed_isteners,uniq,bitrate,songname
         if (data_size > 0) {
-            listeners_start = strstr(strtolower(recv_buf), "<body>");
-            listeners_end = strchr(listeners_start, ',');
-            if (listeners_start != NULL && listeners_end != NULL) {
-                listeners = listeners_start + strlen("<body>");
-                *listeners_end = '\0';
+            int listener = sc_parse_sc1_response(recv_buf);
+            if (listener != -1) {
                 server_version = SC_VERSION_1;
-                return atoi(listeners);
             }
+            return listener;
         }
     }
 
