@@ -49,7 +49,7 @@ void sock_init(void)
 
 int sock_connect(const char *addr, unsigned int port, sock_proto_t proto, int timout_ms)
 {
-    int sock;
+    int sock = -1;
     int ret;
     char port_str[8];
     struct addrinfo hints, *infoptr, *p; // So no need to use memset global variables
