@@ -96,8 +96,9 @@ int strrpl(char **dest, char *search, char *replace, int mode)
     // how many strings do we need to replace?
     if (mode == MODE_ALL) {
         temp = *dest;
-        for (count = 0; (temp = strstr(temp, search)); count++)
+        for (count = 0; (temp = strstr(temp, search)); count++) {
             temp += search_len;
+        }
     }
     else {
         count = 1;
@@ -124,7 +125,7 @@ int strrpl(char **dest, char *search, char *replace, int mode)
             strcat(result, replace);
             temp = loc + strlen(search);
         }
-        // append remaininc characaters (if any)
+        // append remaining characaters (if any)
         if (strlen(temp) > 0) {
             strcat(result, temp);
         }
