@@ -19,15 +19,14 @@
 enum {
     MODE_ALL = 0,
     MODE_FIRST = 1,
-    MODE_LAST = 2
+    MODE_LAST = 2,
 };
 
+// replaces all strings "replace" with "search" in "dest"
+int strrpl(char **dest, char *search, char *replace, int mode);
 
-//replaces all strings "replace" with "search" in "dest"
-int strrpl(char **dest, char *search, char *replace, int mode); 
-
-//inserts string "insert" at position "pos"
-int strinsrt(char **dest, char *insert, char *pos); 
+// inserts string "insert" at position "pos"
+int strinsrt(char **dest, char *insert, char *pos);
 
 // finds last occurrence of substring "needle" in string "haystack"
 char *strrstr(char *haystack, char *needle);
@@ -35,5 +34,10 @@ char *strrstr(char *haystack, char *needle);
 // "Percent encode" reserved characters according to RFC3986 section 2.2 for use in URIs
 void strencoderfc3986(char **buf);
 
+// Converts string "str" to lower case variant
+char *strtolower(char *str);
+
+// Converts string "str" to upper case variant
+char *strtoupper(char *str);
 
 #endif
