@@ -28,24 +28,21 @@
 
 #define AGENT_CLASS      "AutoHotkeyGUI"
 #define AGENT_TITLE      "buttTrayAgent11-03-2021"
-#define AGENT_SHA256     "1e192da5e8b26b5ada1c967dcda68ca1886f1a275dd7c923f0a7a669bb86d4fa"
+#define AGENT_SHA256     "80015491aabc0b6a3470cd375d8304a5b4446b2ee88929e552c03676ca877f53"
 #define AGENT_EXECUTABLE "butt_agent.exe"
 
 static char song_buf[512];
 
-static int check_hash(int print_hash)
+static int check_hash(void)
 {
-    //#warning "REMOVE THIS RETURN FOR PRODUCTION"
-    //    return 0;
-    //#warning "REMOVE THIS RETURN FOR PRODUCTION"
-
     char agent_sha256[65];
     const int salt = 0xA50D;
 
     if (sha256_file((char *)AGENT_EXECUTABLE, agent_sha256, salt) == 0) {
-        if (print_hash == 1) {
-            printf("agent hash: %s\n", agent_sha256);
-        }
+        // #warning "REMOVE THIS RETURN FOR PRODUCTION"
+        //     printf("agent hash: %s\n", agent_sha256);
+        //     return 0;
+        // #warning "REMOVE THIS RETURN FOR PRODUCTION"
 
         if (strncmp(agent_sha256, AGENT_SHA256, 64) == 0) {
             return 0; // correct hash found
@@ -91,7 +88,7 @@ int tray_agent_start(void)
         return 1;
     }
 
-    if (check_hash(0) != 0) {
+    if (check_hash() != 0) {
         return 1; // agent has wrong hash. Do not execute it!
     }
 
@@ -154,16 +151,24 @@ void tray_agent_set_song(char *song)
 int tray_agent_send_cmd(int cmd)
 {
     char msg[512];
-    char server_name[128];
+    char tray_title[128];
+    char custom_window_title[128];
     int minimize;
 
     int pid = GetCurrentProcessId();
 
-    if (cfg.main.num_of_srv > 0) {
-        snprintf(server_name, sizeof(server_name), "%s", cfg.srv[cfg.selected_srv]->name);
+    if (cfg.gui.window_title[0] != '\0') {
+        snprintf(custom_window_title, sizeof(custom_window_title), "%s", cfg.gui.window_title);
     }
     else {
-        snprintf(server_name, sizeof(server_name), "%s", "no server");
+        snprintf(custom_window_title, sizeof(custom_window_title), "dummy");
+    }
+
+    if (cfg.main.num_of_srv > 0) {
+        snprintf(tray_title, sizeof(tray_title), "%s", cfg.srv[cfg.selected_srv]->name);
+    }
+    else {
+        snprintf(tray_title, sizeof(tray_title), "%s", "no server");
     }
 
     switch (cmd) {
@@ -175,17 +180,17 @@ int tray_agent_send_cmd(int cmd)
             }
         }
         minimize = 1;
-        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d", VERSION, minimize, pid, server_name, connected);
+        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d\t%s", VERSION, minimize, pid, tray_title, connected, custom_window_title);
         break;
     case TA_START:
     case TA_SERVER_NAME:
     case TA_CONNECT_STATE:
         minimize = 0;
-        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d", VERSION, minimize, pid, server_name, connected);
+        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d\t%s", VERSION, minimize, pid, tray_title, connected, custom_window_title);
         break;
     case TA_SONG_UPDATE:
         minimize = 0;
-        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d\t%s", VERSION, minimize, pid, server_name, connected, song_buf);
+        snprintf(msg, sizeof(msg), "%s\t%d\t%d\t%s\t%d\t%s\t%s", VERSION, minimize, pid, tray_title, connected, custom_window_title, song_buf);
         break;
     default:
         return 1;
@@ -209,7 +214,7 @@ int tray_agent_stop(void)
     STARTUPINFOA si;
     PROCESS_INFORMATION pi;
 
-    if (check_hash(0) != 0) {
+    if (check_hash() != 0) {
         return 1; // Agent has wrong hash. Do not execute it!
     }
 
