@@ -8,7 +8,7 @@ enum {
     UPDATE_NEW_VERSION = 0,
     UPDATE_SOCKET_ERROR = -1,
     UPDATE_ILLEGAL_ANSWER = -2,
-    UPDATE_UP_TO_DATE = -3
+    UPDATE_UP_TO_DATE = -3,
 };
 
 #endif
