@@ -248,7 +248,7 @@ uint32_t url_post_json(const char *url, char *post_data, char *answer, uint32_t
                 chunk.size = 0;
             }
             /*     else if (response_code != 200) {
-                     printf("html response = %ld\n", response_code);
+                     printf("http response = %ld\n", response_code);
                      chunk.size = 0;
                  }
                  else if (strstr(chunk.memory, "Invalid resource")) { // Shoutcast v1 response with http_code = 200 but "Invalid ressource"
@@ -334,7 +334,7 @@ uint32_t url_post_sdp(const char *url, const char *bearer_token, char *post_data
                 chunk.size = 0;
             }
             /*     else if (response_code != 200) {
-                     printf("html response = %ld\n", response_code);
+                     printf("http response = %ld\n", response_code);
                      chunk.size = 0;
                  }
                  else if (strstr(chunk.memory, "Invalid resource")) { // Shoutcast v1 response with http_code = 200 but "Invalid ressource"
@@ -411,7 +411,7 @@ uint32_t url_post(const char *url, char *post_data, char *answer, uint32_t max_a
                 chunk.size = 0;
             }
             /*     else if (response_code != 200) {
-                     printf("html response = %ld\n", response_code);
+                     printf("http response = %ld\n", response_code);
                      chunk.size = 0;
                  }
                  else if (strstr(chunk.memory, "Invalid resource")) { // Shoutcast v1 response with http_code = 200 but "Invalid ressource"
@@ -556,8 +556,8 @@ uint32_t url_get_listener_count(const char *url, char *data, uint32_t data_size)
                 chunk.size = 0;
             }
             else if (response_code != 200) {
-                // printf("url_get_listener: html response = %ld\n", response_code);
-                write_log("url_get_listener: html response != 200\n");
+                // printf("url_get_listener: http response = %ld\n", response_code);
+                write_log("url_get_listener: http response != 200\n");
                 chunk.size = 0;
             }
             else if (strstr(chunk.memory, "Invalid resource")) { // Shoutcast v1 response with http_code = 200 but "Invalid ressource"
