@@ -33,6 +33,6 @@ struct vu_led_t {
 };
 
 void vu_init(void);
-void vu_meter(float left, float right);
+void vu_meter(float left, float right, float l_peak, float r_peak);
 
 #endif
